searchData={"items":[{"type":"module","title":"LiveMonacoEditor","doc":"Monaco Editor  component for Phoenix LiveView.","ref":"LiveMonacoEditor.html"},{"type":"module","title":"Features - LiveMonacoEditor","doc":"- [Lazy load](https://github.com/suren-atoyan/monaco-loader) assets\n- Easily instantiate [single](https://github.com/BeaconCMS/live_monaco_editor#usage) or [multpiple](https://github.com/BeaconCMS/live_monaco_editor#multiple-editors) editors\n- Pass any [option available](https://microsoft.github.io/monaco-editor/docs.html#interfaces/editor.IStandaloneEditorConstructionOptions.html) to the editor\n- [Interoperability](https://github.com/BeaconCMS/live_monaco_editor#interface) with the underlying editor","ref":"LiveMonacoEditor.html#module-features"},{"type":"module","title":"Installation - LiveMonacoEditor","doc":"Add `:live_monaco_editor` dependency:\n\n```elixir\ndef deps do\n  [\n    {:live_monaco_editor, \"~> 0.1\"}\n  ]\nend\n```\n\nOnce installed, change your `assets/js/app.js` file to load the code editor hook in the live socket:\n\n```javascript\nimport { CodeEditorHook } from \"../../deps/live_monaco_editor/priv/static/live_monaco_editor.esm\"\n\nlet Hooks = {}\nHooks.CodeEditorHook = CodeEditorHook\n\nlet liveSocket = new LiveSocket(\"/live\", Socket, { hooks: Hooks, params: { _csrf_token: csrfToken } })\n```\n\nAnd change your `assets/css/app.css` file to load styling:\n\n```css\n@import \"../../deps/live_monaco_editor/priv/static/live_monaco_editor.min.css\";\n```","ref":"LiveMonacoEditor.html#module-installation"},{"type":"module","title":"Usage - LiveMonacoEditor","doc":"A new editor using the default options can be created as:\n\n```heex\n \n```\n\nOr you can customize it as:\n\n```heex\n \n```\n\n![Elixir](https://raw.github.com/BeaconCMS/live_monaco_editor/main/assets/elixir.png)","ref":"LiveMonacoEditor.html#module-usage"},{"type":"module","title":"Interface - LiveMonacoEditor","doc":"","ref":"LiveMonacoEditor.html#module-interface"},{"type":"module","title":"Set editor options - LiveMonacoEditor","doc":"All [monaco editor options](https://microsoft.github.io/monaco-editor/docs.html#interfaces/editor.IStandaloneEditorConstructionOptions.html) are supported by passing a map to `opts`, for example to change the initial language and some other visual options:\n\n```heex\n \n```","ref":"LiveMonacoEditor.html#module-set-editor-options"},{"type":"module","title":"Merge with default options - LiveMonacoEditor","doc":"The code editor is created with default options to provide a better UX out-of-the-box, which may not suit your needs, but you can keep the defaults and overwrite some options as you wish:\n\n```heex\n \n```","ref":"LiveMonacoEditor.html#module-merge-with-default-options"},{"type":"module","title":"Fetching the editor value - LiveMonacoEditor","doc":"You can listen to events emitted by the code editor to fetch its current value and send it back to the parent LiveView where the component is used. Firstly, add a event listener:\n\n```javascript\nwindow.addEventListener(\"lme:editor_mounted\", (ev) => {\n  const hook = ev.detail.hook\n\n  // https://microsoft.github.io/monaco-editor/docs.html#interfaces/editor.IStandaloneCodeEditor.html\n  const editor = ev.detail.editor.standalone_code_editor\n\n  // push an event to the parent liveview containing the editor current value when the editor loses focus\n  editor.onDidBlurEditorWidget(() => {\n    hook.pushEvent(\"code-editor-lost-focus\", { value: editor.getValue() })\n  })\n})\n```\n\nThen you can handle that event on the LiveView to save the editor content or perform any kind of operation you need:\n\n```elixir\ndef handle_event(\"code-editor-lost-focus\", %{\"value\" => value}, socket) do\n  {:noreply, assign(socket, :source, value)}\nend\n```","ref":"LiveMonacoEditor.html#module-fetching-the-editor-value"},{"type":"module","title":"Inside forms - LiveMonacoEditor","doc":"Do not rely on `phx-change` to fetch the editor content because it has known limitations due to how Monaco Editor works:\n\n- Pressing \"backspace\" does not trigger the change event.\n- [Only the last 10 lines](https://github.com/BeaconCMS/live_monaco_editor/issues/14) are sent in the event value.\n\nInstead use the `:change` option in the component:\n\n```heex\n \n   \n \n```\n\nWhich will trigger an event `set_editor_value` in the current LiveView process:\n\n```elixir\ndef handle_event(\"set_editor_value\", %{\"value\" => value}, socket) do\n  # do something with `value` - it contains the whole editor content\n  {:noreply, socket}\nend\n```\n\nYou'll need to ignore phx-change events for the editor field:\n\n```elixir\ndef handle_event(\"validate\", %{\"_target\" => [\"live_monaco_editor\", \"my_file.html\"]}, socket) do\n  # ignore change events from the editor field\n  {:noreply, socket}\nend\n```","ref":"LiveMonacoEditor.html#module-inside-forms"},{"type":"module","title":"Multiple editors - LiveMonacoEditor","doc":"Set an unique `id` and `path` for each one:\n\n```heex\n \n \n```","ref":"LiveMonacoEditor.html#module-multiple-editors"},{"type":"module","title":"Change language and value - LiveMonacoEditor","doc":"```heex\n my_file.html \n```\n\n```elixir\ndef handle_event(\"create-file\", _params, socket) do\n  {:noreply,\n   socket\n   |> LiveMonacoEditor.change_language(\"html\")\n   |> LiveMonacoEditor.set_value(\" New File \")}\nend\n```\n\n_More operations will be supported in new releases._","ref":"LiveMonacoEditor.html#module-change-language-and-value"},{"type":"module","title":"Styling - LiveMonacoEditor","doc":"The component does not depend on any CSS framework but its parent container has to be large enough to be visible. The default style can be changed and/or classes can be applied:\n\n```heex\n \n```","ref":"LiveMonacoEditor.html#module-styling"},{"type":"module","title":"Status - LiveMonacoEditor","doc":"Early-stage, you can expect incomplete features and breaking changes.","ref":"LiveMonacoEditor.html#module-status"},{"type":"module","title":"Contributing - LiveMonacoEditor","doc":"You can use the file `dev.exs` which is a self-contained Phoenix application running LiveMonacoEditor. Execute:\n\n```sh\nmix setup\niex -S mix dev\n```\n\nVisit http://localhost:4002","ref":"LiveMonacoEditor.html#module-contributing"},{"type":"module","title":"Looking for help with your Elixir project? - LiveMonacoEditor","doc":"At DockYard we are [ready to help you build your next Elixir project](https://dockyard.com/phoenix-consulting).\nWe have a unique expertise in Elixir and Phoenix development that is unmatched and we love to [write about Elixir](https://dockyard.com/blog/categories/elixir).\n\nHave a project in mind? [Get in touch](https://dockyard.com/contact/hire-us)!","ref":"LiveMonacoEditor.html#module-looking-for-help-with-your-elixir-project"},{"type":"module","title":"Acknowledgements - LiveMonacoEditor","doc":"* [Jonatan Kłosko](https://github.com/jonatanklosko) for his amazing work with [Livebook Editor](https://github.com/livebook-dev/livebook/blob/main/assets/js/hooks/cell_editor.js)\n* [Logo](https://www.flaticon.com/free-icons/script) created by kerismaker - Flaticon\n* [Logo font](https://fonts.google.com/specimen/Source+Code+Pro) designed by Paul D. hunt","ref":"LiveMonacoEditor.html#module-acknowledgements"},{"type":"function","title":"LiveMonacoEditor.change_language/3","doc":"Change the editor's language.","ref":"LiveMonacoEditor.html#change_language/3"},{"type":"function","title":"Examples - LiveMonacoEditor.change_language/3","doc":"LiveMonacoEditor.change_language(socket, \"markdown\", to: \"my_file.md\")","ref":"LiveMonacoEditor.html#change_language/3-examples"},{"type":"function","title":"Options - LiveMonacoEditor.change_language/3","doc":"* `:to` - the editor's `path` name that will get the language changed. Defaults to \"file\".\n\nSee https://microsoft.github.io/monaco-editor/docs.html#functions/editor.setModelLanguage.html for more info.","ref":"LiveMonacoEditor.html#change_language/3-options"},{"type":"function","title":"LiveMonacoEditor.code_editor/1","doc":"Renders a monaco editor [model](https://microsoft.github.io/monaco-editor/docs.html#functions/editor.createModel.html).","ref":"LiveMonacoEditor.html#code_editor/1"},{"type":"function","title":"Examples - LiveMonacoEditor.code_editor/1","doc":"Render a simple editor using default options:\n\n     \n\nOr merge with custom options:","ref":"LiveMonacoEditor.html#code_editor/1-examples"},{"type":"function","title":"Attributes - LiveMonacoEditor.code_editor/1","doc":"* `path` (`:string`) - file identifier, pass unique names to render multiple editors. Defaults to `\"file\"`.\n* `value` (`:string`) - initial content. Defaults to `\"\"`.\n* `change` (`:string`) - event name to capture editor content changes, see https://github.com/BeaconCMS/live_monaco_editor#inside-forms for more info. Defaults to `\"\"`.\n* `target` (`:string`) - target for editor events in order to use with LiveComponent, see https://github.com/BeaconCMS/live_monaco_editor#inside-forms for more info. Defaults to `\"\"`.\n* `opts` (`:map`) - options for the monaco editor instance","ref":"LiveMonacoEditor.html#code_editor/1-attributes"},{"type":"function","title":"Example - LiveMonacoEditor.code_editor/1","doc":"%{\n        \"language\" => \"markdown\",\n        \"fontSize\" => 12,\n        \"wordWrap\" => \"on\"\n      }\n\n  See all available options at https://microsoft.github.io/monaco-editor/docs.html#interfaces/editor.IStandaloneEditorConstructionOptions.html\n\n  Defaults to `%{\"fontFamily\" => \"JetBrains Mono, monospace\", \"fontSize\" => 14, \"formatOnPaste\" => true, \"formatOnType\" => true, \"guides\" => %{\"indentation\" => false}, \"language\" => \"markdown\", \"minimap\" => %{\"enabled\" => false}, \"occurrencesHighlight\" => false, \"parameterHints\" => true, \"renderLineHighlight\" => \"none\", \"scrollBeyondLastLine\" => false, \"scrollbar\" => %{\"alwaysConsumeMouseWheel\" => false}, \"suggestSelection\" => \"first\", \"tabCompletion\" => \"on\", \"tabIndex\" => -1, \"tabSize\" => 2, \"theme\" => \"default\"}`.\n* `style` (`:string`) - Defaults to `\"min-height: 100px; width: 100%;\"`.\n* Global attributes are accepted. the arbitrary HTML attributes to add to the editor container element.","ref":"LiveMonacoEditor.html#code_editor/1-example"},{"type":"function","title":"LiveMonacoEditor.default_opts/0","doc":"The default Monaco Editor opts passed to `<.code_editor>`","ref":"LiveMonacoEditor.html#default_opts/0"},{"type":"function","title":"LiveMonacoEditor.set_value/3","doc":"Change the editor's `value` (content).","ref":"LiveMonacoEditor.html#set_value/3"},{"type":"function","title":"Examples - LiveMonacoEditor.set_value/3","doc":"LiveMonacoEditor.set_value(socket, \"Enum.all?([1, 2, 3])\", to: \"my_script.exs\")","ref":"LiveMonacoEditor.html#set_value/3-examples"},{"type":"function","title":"Options - LiveMonacoEditor.set_value/3","doc":"* `:to` - the editor's `path` name that will get the value updated. Defaults to \"file\".\n\nSee https://microsoft.github.io/monaco-editor/docs.html#interfaces/editor.IStandaloneCodeEditor.html#setValue for more info.","ref":"LiveMonacoEditor.html#set_value/3-options"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"0.2.0 (2024-12-05) - Changelog","doc":"","ref":"changelog.html#0-2-0-2024-12-05"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Support Phoenix LiveView 1.0\n  * Update Monaco Editor to 0.52.0\n  * Relax phoenix dependency to `~> 1.6`\n  * Relax phoenix_live_view dependency to `~> 0.16`\n  * Relax jason dependency to `~> 1.3`","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.8 (2024-02-08) - Changelog","doc":"","ref":"changelog.html#0-1-8-2024-02-08"},{"type":"extras","title":"Enhancements - Changelog","doc":"* [Add action to toggle word wrapping](https://github.com/BeaconCMS/live_monaco_editor/pull/20)\n  * [Add support for targeted events](https://github.com/BeaconCMS/live_monaco_editor/pull/21)","ref":"changelog.html#enhancements"},{"type":"extras","title":"Bug fixes - Changelog","doc":"* Replace `monaco-editor@latest` with `monaco-editor@0.45.0` to avoid upstream breaking changes or bugs","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"0.1.7 (2023-11-08) - Changelog","doc":"","ref":"changelog.html#0-1-7-2023-11-08"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `:change` option to capture editor content changes","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.6 (2023-09-18) - Changelog","doc":"","ref":"changelog.html#0-1-6-2023-09-18"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Auto resize editor on content or viewport change\n  * Change default options to improve default look & feel","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.5 (2023-09-15) - Changelog","doc":"","ref":"changelog.html#0-1-5-2023-09-15"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Always load latest monaco editor package version","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.4 (2023-08-14) - Changelog","doc":"","ref":"changelog.html#0-1-4-2023-08-14"},{"type":"extras","title":"Bug fixes - Changelog","doc":"* Add `display: contents` to wrapper div - [lukad](https://github.com/lukad)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"0.1.3 (2023-06-28) - Changelog","doc":"","ref":"changelog.html#0-1-3-2023-06-28"},{"type":"extras","title":"Bug fixes - Changelog","doc":"* DOM patch conflict causing the editor to stop receiving some keystrokes","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"0.1.2 (2023-06-10) - Changelog","doc":"","ref":"changelog.html#0-1-2-2023-06-10"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Load JetBrains Mono font by default\n  * Load OneDark theme by default","ref":"changelog.html#enhancements"},{"type":"extras","title":"Bug fixes - Changelog","doc":"* Remove unnecessary parent ` ` element","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"0.1.1 (2023-06-08) - Changelog","doc":"","ref":"changelog.html#0-1-1-2023-06-08"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Set default theme `vs-dark`","ref":"changelog.html#enhancements"},{"type":"extras","title":"Bug fixes - Changelog","doc":"* Only install and load `esbuild` in `:dev` env","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"0.1.0 (2023-05-23) - Changelog","doc":"","ref":"changelog.html#0-1-0-2023-05-23"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add ` ` component","ref":"changelog.html#enhancements"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}